<?php
/*
 * Plugin Name: Advanced Order Export  - Add columns for different currencies
 * Description: It requires plugin "Advanced Order Export For WooCommerce"
 * Author: AlgolPlus
 * Author URI: https://algolplus.com/
 */

// Add columns for different currencies
// Format - XLS/CSV
class Woe_Multicurrency_Columns {
	var $currencies = array("USD","EUR", "GBP", "CAD", "AUD" ); // tweak this list 
	var $skip_headers = array();
	var $addon_setting = 'use_currency_columns';

    function __construct() {
		//hooks for UI
        add_action("woe_settings_above_buttons", array($this,"draw_options") );
        add_filter("woe_settings_page_prepare",array($this,"maybe_add_order_fields"));
        
		//before start export
		add_filter('woe_settings_validate_defaults', function ($settings) {
			if( !empty($settings[$this->addon_setting]) ) {
 				foreach($settings["order_fields"] as $k=>$v) {
					if( !empty($v['format']) AND $v['format'] == "money" AND $v['checked'] ) 
						$this->skip_headers[] = $v["colname"];
				}
 				add_filter('woe_xls_header_filter',array($this,'tweak_headers'), 10, 1 ); 
 				add_filter('woe_fetch_order',array($this,'fill_order_export'), 10, 2 ); 
			}	
			return $settings;
		} );        
    }
    
    // 1 on/off
    function draw_options($settings){
        $selected = !empty($settings[ $this->addon_setting ]) ? 'checked': '';
        echo '<br><br>
        <input type=hidden name="settings['.$this->addon_setting.']" value="0">
        <input type=checkbox name="settings['.$this->addon_setting.']" value="1" '. $selected .'>
        Create separate columns for each currency ( <b>press "Save settings"</b> after checking this checkbox! )<br>
        Please, mark for export only general fields ( without currency prefix) and press "Save Settings" again.
        <br><br>';
    }
    //2 add fields 
    function maybe_add_order_fields($settings) {
        if( !empty($settings[$this->addon_setting]) ) {
			$new_order_fields = $new_order_fields2 = array();
			foreach($settings["order_fields"] as $k=>$v) {
				$new_order_fields[$k] = $v;
				// for all money fields?
				if( !empty($v['format']) AND $v['format'] == "money") {
					foreach($this->currencies as $cur) {
						$v_new = $v;
						$v_new["colname"] = "{$cur} ". $v_new["colname"];
						$v_new["label"] = "{$cur} ". $v_new["label"];
						//was just $new_order_fields[$k."_".$cur] = $v_new;
						$new_order_fields2[$cur][$k."_".$cur] = $v_new;
					}
				}	
			}
			
			//group by currency 
			foreach ($new_order_fields2 as $cur=>$fields) {
				foreach($fields as $k=>$v)
					$new_order_fields[$k]=$v;
			}
			
			$settings["order_fields"] = $new_order_fields;
        }     
        return $settings;
    }    
    
    //3
    function tweak_headers($headers){
		return array_values( array_diff($headers,$this->skip_headers) ) ; // start from 0 ,no gaps!
    }
    
    //4 fill data 
	function fill_order_export($row,$order){
		$cur = $order->get_currency();
		$mask = '#^(.+)_'.$cur.'$#';
		foreach($row as $k=>$v){
			if(preg_match($mask,$k,$matches) ) {
				$row[$k] = $row[$matches[1]];
				unset($row[$matches[1]]); //remove original value 
			}
		}
		return $row;
	}
}
new Woe_Multicurrency_Columns();